@@ -1,5 +1,9 @@
+from alephvault.evm_http_storage.methods.common.erc721 import ERC721Collections, ERC721CollectionOf, ERC721Reset
+
+
 def make_evm_erc721_balance_resource(db_name: str = 'evm', erc721balance_collection_name: str = 'erc721-ownership',
-                                     erc721balance_resource_name: str = "evm-erc721-ownership"):
+                                     erc721balance_resource_name: str = "evm-erc721-ownership",
+                                     state_db_name: str = 'evm', state_collection_name: str = 'state'):
     """
     Makes an EVM resource to track token ownerships of an ERC-721 smart contract.
     :return: A dictionary with the resource configuration.
@@ -36,6 +40,20 @@ def make_evm_erc721_balance_resource(db_name: str = 'evm', erc721balance_collect
                 "owned-list": {
                     "fields": ["contract-key", "owner"]
                 }
+            },
+            "methods": {
+                "collections": {
+                    "type": "view",
+                    "handler": ERC721Collections()
+                },
+                "collection-of": {
+                    "type": "view",
+                    "handler": ERC721CollectionOf()
+                },
+                "reset-cache": {
+                    "type": "operation",
+                    "handler": ERC721Reset(state_db_name, state_collection_name)
+                }
             }
         }
     }
